# ape.contracts

```{eval-rst}
.. autoclass:: ape.contracts.base.ContractTypeWrapper
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.contracts.base.ContractInstance
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __init__
```

```{eval-rst}
.. autoclass:: ape.contracts.base.ContractContainer
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __call__, __init__
```

```{eval-rst}
.. autoclass:: ape.contracts.base.ContractEvent
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __call__, __init__
```

```{eval-rst}
.. autoclass:: ape.contracts.base.ContractError
    :members:
    :show-inheritance:
    :special-members:
    :exclude-members: __repr__, __weakref__, __metaclass__, __call__, __init__
```
